X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/999d9a9f795cfc745681989ae0f30e531cde059f..3328e0ca268b7bb1bdc33c3bd5a8bf2b687085c7:/include/wx/xrc/xh_spin.h

diff --git a/include/wx/xrc/xh_spin.h b/include/wx/xrc/xh_spin.h
index 9d44a0ffe9..a6cf9fc27f 100644
--- a/include/wx/xrc/xh_spin.h
+++ b/include/wx/xrc/xh_spin.h
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_spin.h
 // Purpose:     XML resource handler for wxSpinButton
 // Author:      Bob Mitchell
 // Created:     2000/03/21
 // RCS-ID:      $Id$
@@ -11,45 +11,39 @@
 #ifndef _WX_XH_SPIN_H_
 #define _WX_XH_SPIN_H_
 
-#ifdef __GNUG__
-#pragma interface "xh_spin.h"
-#endif
-
 #include "wx/xrc/xmlres.h"
-#include "wx/defs.h"
+
+#if wxUSE_XRC
 
 #if wxUSE_SPINBTN
-class WXXMLDLLEXPORT wxSpinButtonXmlHandler : public wxXmlResourceHandler
-{
-    enum
-    {
-        wxSP_DEFAULT_VALUE = 0,
-        wxSP_DEFAULT_MIN = 0,
-        wxSP_DEFAULT_MAX = 100
-    };
 
+class WXDLLIMPEXP_XRC wxSpinButtonXmlHandler : public wxXmlResourceHandler
+{
 public:
     wxSpinButtonXmlHandler();
     virtual wxObject *DoCreateResource();
     virtual bool CanHandle(wxXmlNode *node);
+
+    DECLARE_DYNAMIC_CLASS(wxSpinButtonXmlHandler)
 };
-#endif
+
+#endif // wxUSE_SPINBTN
+
 
 #if wxUSE_SPINCTRL
-class WXXMLDLLEXPORT wxSpinCtrlXmlHandler : public wxXmlResourceHandler
-{
-    enum
-    {
-        wxSP_DEFAULT_VALUE = 0,
-        wxSP_DEFAULT_MIN = 0,
-        wxSP_DEFAULT_MAX = 100
-    };
 
+class WXDLLIMPEXP_XRC wxSpinCtrlXmlHandler : public wxXmlResourceHandler
+{
 public:
     wxSpinCtrlXmlHandler();
     virtual wxObject *DoCreateResource();
     virtual bool CanHandle(wxXmlNode *node);
+
+    DECLARE_DYNAMIC_CLASS(wxSpinCtrlXmlHandler)
 };
-#endif
+
+#endif // wxUSE_SPINCTRL
+
+#endif // wxUSE_XRC
 
 #endif // _WX_XH_SPIN_H_
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        xh_spin.h
-// Purpose:     XML resource handler for wxSpinButton
+// Name:        wx/xrc/xh_spin.h
+// Purpose:     XML resource handler for wxSpinButton and wxSpinCtrl
 // Author:      Bob Mitchell
 // Created:     2000/03/21